@@ -315,7 +315,7 @@ class GrapheneShardedMeshSource(GrapheneUnshardedMeshSource):
       for label, raw_binary in output.items() 
     }
 
-  def download_segid(self, seg_id, bounding_box, bypass=False, use_byte_offsets=False):    
+  def download_segid(self, seg_id, bounding_box, bypass=False, use_byte_offsets=True):    
     """See GrapheneUnshardedMeshSource.get for the user facing function."""
     level = self.meta.meta.decode_layer_id(seg_id)
     if level not in self.readers:
