@@ -2,6 +2,7 @@ import os
 
 from .metadata import PrecomputedMeshMetadata
 from .unsharded import UnshardedLegacyPrecomputedMeshSource
+from .multilod import ShardedMultiLevelPrecomputedMeshSource, UnshardedMultiLevelPrecomputedMeshSource
 
 
 from ..metadata import PrecomputedMetadata
@@ -14,11 +15,16 @@ from ....cloudvolume import SharedConfiguration
 class PrecomputedMeshSource(object):
   def __new__(cls, meta, cache, config, readonly=False):
     mesh_meta = PrecomputedMeshMetadata(meta, cache)
-
-    if mesh_meta.is_sharded():
-      print(red("This mesh volume is sharded. Mesh shard support is coming but is not available yet."))
-      # return ShardedLegacyPrecomputedMeshSource(mesh_meta, cache, config, readonly) 
-
+    if mesh_meta.info.get('@type', None) == 'neuroglancer_multilod_draco':
+      sharding = mesh_meta.info.get('sharding', None)
+      if sharding and sharding['@type'] == 'neuroglancer_uint64_sharded_v1':
+        # Sharded storage of multi-resolution mesh fragment data
+        return ShardedMultiLevelPrecomputedMeshSource(mesh_meta, cache, config, readonly) 
+      else:
+        # Unsharded storage of multi-resolution mesh fragment data
+        return UnshardedMultiLevelPrecomputedMeshSource(mesh_meta, cache, config, readonly)
+  
+    # Legacy single-resolution mesh format
     return UnshardedLegacyPrecomputedMeshSource(mesh_meta, cache, config, readonly)
 
   @classmethod
@@ -43,4 +49,6 @@ class PrecomputedMeshSource(object):
     cloudpath, mesh_dir = os.path.split(cloudpath)
     meta = PrecomputedMetadata(cloudpath, cache, info={ 'mesh': mesh_dir })
 
-    return PrecomputedMeshSource(meta, cache, config)
\ No newline at end of file
+    return PrecomputedMeshSource(meta, cache, config)
+
+
