@@ -125,14 +125,11 @@ class PrecomputedMetadata(object):
 
     if redirect is not None:
       info['redirect'] = str(redirect)
-    
-    fullres = info['scales'][0]
-    factor_in_mip = factor.clone()
  
     # add mip levels
-    for _ in range(max_mip):
-      scale = cls.add_scale(None, factor, encoding=encoding, chunk_size=chunk_size, info=info)
-      info["scales"].append(scale)
+    # the max_mip should be inclusive
+    for mip in range(max_mip + 1):
+      cls.add_scale(None, factor ** mip, encoding=encoding, chunk_size=chunk_size, info=info)
 
     if encoding == 'compressed_segmentation':
       info['scales'][0]['compressed_segmentation_block_size'] = list(map(int, compressed_segmentation_block_size))
@@ -630,10 +627,10 @@ Hops:
     self.info['scales'] = self.info['scales'][0:1]
 
   def add_resolution(self, res, encoding=None, chunk_size=None, info=None):
-    if isinstance(res[0], float):
+    if lib.floating(res):
       factor = Vec(*res, dtype=float) / self.resolution(0)
     else:
-      factor = Vec(*res, dtype=float) // self.resolution(0)
+      factor = Vec(*res) // self.resolution(0)
 
     return self.add_scale(factor, encoding, chunk_size, info)
 
