@@ -1,3 +1,4 @@
+from typing import Union
 import decimal
 from functools import reduce
 import json
@@ -69,6 +70,14 @@ def first(lst):
   except IndexError:
     return None
 
+def totalfn(iterator, total):
+  if total is not None:
+    return total
+  try:
+    return len(iterator)
+  except TypeError:
+    return None
+
 def sip(iterable, block_size):
   """Sips a fixed size from the iterable."""
   ct = 0
@@ -340,6 +349,18 @@ class Bbox(object):
   def dtype(self):
     return self._dtype
 
+  @property
+  def dx(self):
+    return self.maxpt.x - self.minpt.x
+
+  @property
+  def dy(self):
+    return self.maxpt.y - self.minpt.y
+
+  @property
+  def dz(self):
+    return self.maxpt.z - self.minpt.z  
+
   @classmethod
   def intersection(cls, bbx1, bbx2):
     result = Bbox( [ 0 ] * bbx1.ndim, [ 0 ] * bbx2.ndim )
@@ -633,22 +654,32 @@ class Bbox(object):
   def center(self):
     return (self.minpt + self.maxpt) / 2.0
 
-  def grow(self, amt):
-    assert amt >= 0
+  def adjust(self, amt: Union[int, tuple, list]):
+    if isinstance(amt, tuple) or isinstance(amt, list):
+      assert len(amt) == 3
+      amt = np.asarray(amt)
+
     self.minpt -= amt
     self.maxpt += amt
-    return self
-
-  def shrink(self, amt):
-    assert amt >= 0
-    self.minpt += amt
-    self.maxpt -= amt
-
+    
     if not self.valid():
       raise ValueError("Cannot shrink bbox below zero volume.")
 
     return self
 
+  def shrink(self, amt: Union[int, tuple, list]):
+    if isinstance(amt, int):
+      assert amt > 0
+    elif isinstance(amt, tuple) or isinstance(amt, list):
+      for item in amt:
+        assert item > 0
+
+    # make it negative for shrink
+    return self.adjust(-amt)
+
+  def grow(self, amt: Union[int, tuple, list]):
+    return self.adjust(amt)
+
   def expand_to_chunk_size(self, chunk_size, offset=Vec(0,0,0, dtype=int)):
     """
     Align a potentially non-axis aligned bbox to the grid by growing it
@@ -944,4 +975,4 @@ def save_images(
       path = os.path.join(directory, filename)
       img2d.save(path, image_format)
 
-  return toabs(directory)
\ No newline at end of file
+  return toabs(directory)
